********************************
The sherpa.astro.ui.utils module
********************************

.. currentmodule:: sherpa.astro.ui.utils

.. automodule:: sherpa.astro.ui.utils

The :py:mod:`sherpa.astro.ui.utils` module contains the Astronomy-specific
:py:class:`~sherpa.astro.ui.utils.Session` class that provides the
data-management code used by the :py:mod:`sherpa.astro.ui` module.
                
   .. rubric:: Classes
               
   .. autosummary::
      :toctree: api

      Session
      
Class Inheritance Diagram
=========================

.. inheritance-diagram:: Session
   :parts: 1
